# freetshirts

freetshirts is a Python library to send customized emails to 1500+ colleges requesting free merchandise.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install freetshirts.

```bash
pip install freetshirts
```

## Usage

```python
import freetshirts

#this function will take your user input to customize your message!
#Once you have entered the inputs, make sure to confirm you want to send the email, and your email will be off to 1500+ colleges!
freetshirts.send_email()
```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

## License
[MIT](https://choosealicense.com/licenses/mit/)
